{% extends 'base.html' %}

{% block content %}
<div class="row sortable ui-sortable">
  <div class="col-xs-12" data-original-title="">
    <div class="col-xs-1"><h2><i class="fa fa-gears"></i></h2></div>
    <div class="col-xs-10"><h2><span class="break"></span>Services</h2></div>
    <div class="col-xs-1 text-right">
      <h2><a href="{% url "create-service" %}" title="New service"><i class="glyphicon glyphicon-plus"></i></a></h2>
    </div>
  </div>
  <div class="col-xs-12">
    {% include 'cabotapp/_service_list.html' %}
  </div>
</div>
{% endblock content %}

{% block js %}
{% load compress %}
{{ block.super }}
{% compress js %}
<script type="text/coffeescript">
  $('.datatable').dataTable
    sDom: "<'row-fluid'<'span6'l><'span6'f>r>t<'row-fluid'<'span12'i><'span12 center'p>>"
    sPaginationType: "bootstrap"
    iDisplayLength: 100
    oLanguage:
      sLengthMenu: "_MENU_ records per page"
    fnDrawCallback: () ->
      $('.sparktristate').sparkline('html', {type: 'tristate'})
</script>
{% endcompress %}
{% endblock js %}
