{% extends 'base.html' %}

{% block content %}
<div class="container-fluid">
  <div class="row">
    <div class="col-sm-3 col-md-2 sidebar">
      <ul class="nav nav-sidebar">
          <li><a href="General">General</a></li>
        {% for alert in alert_preferences %}
          <li><a href="{{ alert.title }}">{{ alert.title }}</a></li>
        {% endfor %}
      </ul>
    </div>
    <div class="col-sm-9 col-sm-offset-3 col-md-10 col-md-offset-2 main">
      <h1 class="page-header">User Profile</h1>
      <form class="form-horizontal" action="" method="post" role="form">
        {% csrf_token %}
        {% for field in form %}
        <div class="form-group">
          <label class="col-xs-2 control-label">{{ field.label_tag }}</label>
          <div class="col-xs-10">{{ field }}</div>
        </div>
        {% endfor %}
        <div class="form-group">
          <div class="col-xs-6 col-xs-offset-2">
            <button type="submit" class="btn btn-primary">Submit</button>
            <a href="{% url "dashboard" %}" class="btn">Back to dashboard</a>
          </div>
        </div>

      </form>
    </div>
  </div>
</div>
{% endblock %}

{% load compress %}
{% block js %}
{{ block.super }}
{% compress js %}
<script type="text/coffeescript">


</script>
{% endcompress %}
{% endblock %}
