body{
  padding-top:50px;
}
.form-group {
  ul {
    list-style-type: none;
    padding: 5px 0 0 0;
  }

  input[type="radio"] {
    margin-top: -3px;
  }
}

tr.warning a {
  text-decoration: line-through;
}

#graphite_data_container {
  max-height: 200px;
  overflow: scroll;
}

.ui-autocomplete {
  max-height: 400px;
  overflow-y: scroll;
  font-size: 10px;
}

.jqstooltip {
  display: none;
}

div.dataTables_paginate {
  float: right;
}

div.dataTables_info {
  float: left;
  margin: 20px 0;
}

div.dataTables_length {
  float: right;
}

.messages {
  margin: auto;
  width: 50%;
  margin-top: 10px;
}
