{% extends 'base.html' %}
{% load static from staticfiles %}
{% block title %}{{ block.super }} - About{% endblock title %}

{% block content %}

<div class="cols-xs-11 col-xs-offset-1">
  <h2>About Cabot</h2>
</div>

<div class="cols-xs-11 col-xs-offset-1">
  <hr>
  Version: {{ cabot_version }}
</div>

{% endblock content %}
