{% extends 'base.html' %}

{% block content %}
<h1>Delete service</h1>
<form action="." method="post">{% csrf_token %}
  <button type="submit" class="btn btn-danger">Delete {{ object }}</button>
</form>
{% endblock %}

{% load compress %}
{% block js %}
{{ block.super }}
{% compress js %}
<script type="text/coffeescript">

</script>
{% endcompress %}
{% endblock %}
