{% extends 'base.html' %}

{% block content %}

{% include 'cabotapp/_statuscheck_list.html' with checks_type="All" %}

{% endblock content %}

{% block js %}
{% load compress %}
{{ block.super }}
{% compress js %}
<script type="text/coffeescript">
  $('.datatable').dataTable
    sDom: "<'row-fluid'<'span6'l><'span6'f>r>t<'row-fluid'<'span12'i><'span12 center'p>>"
    sPaginationType: "bootstrap"
    iDisplayLength: 100
    oLanguage:
      sLengthMenu: "_MENU_ records per page"
    fnDrawCallback: () ->
      $('.sparktristate').sparkline('html', {type: 'tristate'})
</script>
{% endcompress %}
{% endblock js %}
