(function(){$('.datatable').dataTable({sDom:"<'row-fluid'<'span6'l><'span6'f>r>t<'row-fluid'<'span12'i><'span12 center'p>>",sPaginationType:"bootstrap",iDisplayLength:100,oLanguage:{sLengthMenu:"_MENU_ records per page"},fnDrawCallback:function(){return $('.sparktristate').sparkline('html',{type:'tristate'});}});}).call(this);