@font-face {
    font-family: 'Roboto';
    src: url("../fonts/Roboto-Bold-webfont.2ad99072841e.woff");
    font-weight: 700;
    font-style: normal;
}

@font-face {
    font-family: 'Roboto';
    src: url("../fonts/Roboto-Regular-webfont.ec39515ae8c6.woff");
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: 'Roboto';
    src: url("../fonts/Roboto-Light-webfont.b446c2399bb6.woff");
    font-weight: 300;
    font-style: normal;
}
